"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteDraft = exports.setDraft = exports.getDraft = exports.getDraftsList = void 0;
const drafts_1 = __importDefault(require("../dao/drafts"));
async function getDraftsList(req, res) {
    try {
        const drafts = await drafts_1.default.getAll(req.headers.tenant, req.user._id);
        if (!drafts)
            throw new Error();
        res.status(200).json(drafts).end();
    }
    catch (err) {
        res.status(500).json({ message: 'error while finding drafts' }).end();
    }
}
exports.getDraftsList = getDraftsList;
async function getDraft(req, res) {
    try {
        const { contextType, contextId } = req.query;
        const draft = await drafts_1.default.getDraft({
            user: req.user._id,
            tenant: req.headers.tenant,
            contextId: contextId || null,
            contextType
        });
        if (!draft)
            throw new Error();
        res.status(200).json(draft).end();
    }
    catch (err) {
        res.status(404).json({ message: 'draft not found' }).end();
    }
}
exports.getDraft = getDraft;
/**
 * for both creating and updating a draft, just like a Map data type
 * the frontend doesn't care if the draft exists or not, it just passes the contextData.
 */
async function setDraft(req, res) {
    try {
        const user = req.user._id;
        const { tenant } = req.headers;
        const { contextType, contextId = null, contextData = {}, contextDisplayName = '', contextRouteParams = {} } = req.body;
        const draft = await drafts_1.default.setDraft({
            user,
            tenant,
            contextType,
            contextId
        }, { contextData, contextDisplayName, contextRouteParams });
        res.status(200).json(draft).end();
    }
    catch (err) {
        res.status(500).json({ message: 'error mutating draft' }).end();
    }
}
exports.setDraft = setDraft;
async function deleteDraft(req, res) {
    try {
        const { contextType, contextId = null } = req.query;
        const { tenant } = req.headers;
        await drafts_1.default.removeDraft({ contextType, contextId, tenant, user: req.user._id });
        res.status(200).json({ success: true }).end();
    }
    catch (err) {
        res.status(500).json({ message: 'couldn\'t delete draft' });
    }
}
exports.deleteDraft = deleteDraft;
